/******************************************************************************
* C Include: Image                                                            *
*                                                                             *
* File:                                                                       *
*    image.h                                                                  *
*                                                                             *
* Description:                                                                *
*    Include file for the functions used to process image data.               *
*                                                                             *
* History:                                                                    *
*    Created    : 20-AUG-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
*                                                                             *
* Copyright (c) 1993, 1994, Association of Universities for Research in       *
* Astronomy, Inc.  All Rights Reserved.                                       *
* Produced under National Aeronautics and Space Administration grant          *
* NAG W-2166.                                                                 *
******************************************************************************/
#ifndef __IMAGE__
#define __IMAGE__

#include "extrctn.h"
#include "generic.h"
#include "header.h"

/***************************
* Image derived data types *
***************************/
typedef short        IMAGE_VALUE;
typedef IMAGE_VALUE* IMAGE_DATA ;

enum image_format { FITS, HHD };         /* Image format for output */
typedef enum image_format IMAGE_FORMAT;  /*    extractions          */

/******************************
* Image functions' prototypes *
******************************/
HEADER     Construct_Image_Header    (/* HEADER       Plate_Header        ,
					 EXTRACTION   Extraction          ,
					 IMAGE_DATA   Image                */);

IMAGE_DATA Decompress_Image          (/* EXTRACTION   Extraction          ,
					 STRING       File_Name_Template   */);

void       Extract_Image             (/* EXTRACTION   Extraction          ,
					 HEADER       Plate_Header        ,
					 STRING       Image_Data_Root_Dir ,
					 STRING       imageFileRoot       ,
					 IMAGE_FORMAT Format               */);

BOOL       FITS_File_Exists          (/* STRING       imageFileRoot        */);

void       Get_Image_Range           (/* IMAGE_DATA   Image               ,
					 IMAGE_DATA   Data_Min            ,
					 IMAGE_DATA   Data_Max             */);

BOOL       HHD_File_Exists           (/* STRING       imageFileRoot        */);

BOOL       HHH_File_Exists           (/* STRING       imageFileRoot        */);


/****************************
* Image include file page 2 *
****************************/

BOOL       Image_File_Exists         (/* STRING       imageFileRoot       ,
					 IMAGE_FORMAT Format               */);

STRING     Make_Plate_File_Name_Template
                                     (/* STRING       Image_Data_Directory,
					 STRING       Plate_Name           */);

void       Set_Tile_File_Name_Extension
                                     (/* STRING       FileName            ,
					 char         ExtensionCharacter1 ,
					 char         ExtensionCharacter2  */);

#endif
